CA01-Cl05
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Section |
clickAndWait | link=Añadir section |
type | id_name_es | ñç
type | id_slug | nc
clickAndWait | _continue |
verifyTextNotPresent | error |
type | id_name_es | long name and string 1234abcd1234abcd1234abcd 1234abcd1234abcd1234abcd 1234abcd1234abcd1234abcd
clickAndWait | _continue |
verifyTextNotPresent | error |
clickAndWait | link=Sections |
clickAndWait | link=long name and string 1234abcd1234abcd1234abcd 1234abcd1234abcd1234abcd 1234abcd1234abcd1234abcd |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |